#include <QMessageBox>
#include <QDebug>
#include "mainwindow.h"
#include "ui_mainwindow.h"
#include "departmodel.h"
#include "departdelegate.h"

MainWindow::MainWindow(QWidget *parent) :
    QMainWindow(parent),
    ui(new Ui::MainWindow)
{
    ui->setupUi(this);

    depModel = new departModel(this);
    ui->departTableView->setModel(depModel);
    departDelegate * dDelegate = new departDelegate(ui->departTableView);
    ui->departTableView->setItemDelegateForColumn(3,dDelegate);
    ui->departTableView->setEditTriggers(QAbstractItemView::AllEditTriggers);

    timer = new QTimer(this);
    connect(timer,SIGNAL(timeout()),this,SLOT(timerTimeout()));

    rGare = new rechercheGare(this);
    connect(rGare,SIGNAL(resConnu(QList<QPair<QString,QString> >)),this,SLOT(listeGareConnue(QList<QPair<QString,QString> >)));
    connect(rGare,SIGNAL(erreurReseau(QString)),this,SLOT(erreurRechercheGare(QString)));

    dTrains = new departTrains(this);
    connect(dTrains,SIGNAL(departsConnus(QList<ligneDepart>)),this,SLOT(listeDepartsConnus(QList<ligneDepart>)));
}

MainWindow::~MainWindow()
{
    delete ui;
}

void MainWindow::changeEvent(QEvent *e)
{
    QMainWindow::changeEvent(e);
    switch (e->type()) {
    case QEvent::LanguageChange:
        ui->retranslateUi(this);
        break;
    default:
        break;
    }
}

void MainWindow::on_recherchePushButton_clicked()
{
    if (ui->rechercheLineEdit->text().isEmpty())
    {
        QMessageBox::warning(this,tr("Recherche de gare"),tr("Veuillez renseigner le champ de recherche."),QMessageBox::Ok);
        return;
    }
    ui->recherchePushButton->setEnabled(false);
    rGare->demandeServeur(ui->rechercheLineEdit->text());

}

void MainWindow::listeGareConnue(QList<QPair<QString, QString> >listeGare)
{
    ui->garesComboBox->clear();
    while (!listeGare.isEmpty())
    {
        QPair <QString,QString> pairGare = listeGare.takeFirst();
        ui->garesComboBox->addItem(pairGare.second,pairGare.first);
    }
    ui->recherchePushButton->setEnabled(true);
}

void MainWindow::erreurRechercheGare(QString error)
{
    QMessageBox::critical(this,tr("Recherche de gare"),tr("Erreur réseau.\nDétails:") + error,QMessageBox::Ok);
    ui->recherchePushButton->setEnabled(true);
}

void MainWindow::on_garesComboBox_currentIndexChanged(int index)
{
    ui->departsGroupBox->setTitle(tr("Trains au départ de: ") + ui->garesComboBox->currentText());
    if (ui->garesComboBox->itemData(index) != QVariant::Invalid)
    {
        idGareCourante = ui->garesComboBox->itemData(index).toString();
        if (!idGareCourante.isEmpty())
        {
            QList<ligneDepart> ld;
            depModel->setDepartListe(ld);
            dTrains->demandeDeparts(idGareCourante);
            if (!timer->isActive())
                timer->start(1000*60);
        }
    }

}

void MainWindow::listeDepartsConnus(QList<ligneDepart>listeLignesDeparts)
{    
    //qDebug() << "Nbre de départs: " << listeLignesDeparts.size();
    depModel->setDepartListe(listeLignesDeparts);    
    ui->departTableView->resizeColumnsToContents();
}

void MainWindow::timerTimeout()
{
    if (!idGareCourante.isEmpty())
        dTrains->demandeDeparts(idGareCourante);
}
